@@ -16,7 +16,7 @@ fatal(char *s) {
 int
 number_of_columns() {
     int fda;
-    char rc[2];
+    unsigned char rc[2];	/* unsigned: Ranty@soon.com */
 
     if((fda = open("/dev/vcsa0", O_RDONLY)) < 0)
 	fatal("/dev/vcsa0");
