@@ -21,7 +21,7 @@ main(int argc, char *argv[]) {
     fd = getfd();
     num = atoi(argv[1]);
     if (ioctl(fd,VT_ACTIVATE,num)) {
-	perror("VT_ACTIVATE");
+	perror("chvt: VT_ACTIVATE");
 	exit(1);
     }
     if (ioctl(fd,VT_WAITACTIVE,num)) {
