@@ -16,6 +16,9 @@ FILE *findfile(char *fnam, char **dirpath, char **suffixes) {
         char **dp, **sp;
 	FILE *fp;
 
+	/* We might strip a `.gz' if given explicitly,
+	   as in "loadkeys ./keymap.gz".  Maybe later. */
+
 	ispipe = 0;
 	for (dp = dirpath; *dp; dp++) {
 	    if (*fnam == '/' && **dp)
