@@ -3,10 +3,18 @@
 #include <asm/ioctls.h>
 #include <linux/kd.h>
 
+#ifndef USE_LIBC
+/* There is such function in libc5 but it doesn't work for me [libc 5.4.13] */
+#include "wctomb.c"
+#define wctomb our_wctomb
+#endif
+
 extern int getfd();
 extern char *malloc();
 
 main(){
+    char mb[]={0,0,0,0,0,0,0,0};
+    unsigned mb_length;
     int fd, ct;
     struct unimapdesc ud;
     int i;
@@ -34,7 +42,11 @@ main(){
 	   first and second ioctl, so the above errors
 	   are not impossible */
     }
-    printf("count=%d\n", ud.entry_ct);
-    for(i=0; i<ud.entry_ct && i<ct; i++)
-      printf("0x%02x\tU+%04x\n", ud.entries[i].fontpos, ud.entries[i].unicode);
+    printf("# count=%d\n", ud.entry_ct);
+    for(i=0; i<ud.entry_ct && i<ct; i++) {
+	 mb_length=wctomb (mb, ud.entries[i].unicode);
+	 mb[ (mb_length > 6) ? 0 : mb_length ] = 0 ;
+	 printf("0x%03x\tU+%04x\t# %s \n", ud.entries[i].fontpos,
+		ud.entries[i].unicode, mb);
+    }
 }
