@@ -9,6 +9,9 @@
 #include <sys/ioctl.h>
 #include <linux/types.h>
 #include <linux/kd.h>
+
+extern int getfd(void);
+
 void
 usage(){
     fprintf(stderr, "usage: kbd_mode [-a|-u|-k|-s]\n");
@@ -19,11 +22,8 @@ int
 main(int argc, char *argv[]){
         int fd, mode;
 
-	fd = open("/dev/console", 0);
-	if (fd < 0) {
-	        perror("kbd_mode: cannot open /dev/console\n");
-		fd = 0;	    /* let us hope stdin points at a VT */
-	}
+	fd = getfd();
+
 	if (argc == 1) {
 	    /* report mode */
 	    if (ioctl(fd, KDGKBMODE, &mode)) {
