@@ -456,104 +456,8 @@ static char *iso_8859_8_syms[] = {
     "resh", "shin", "tav", "", "", "", "", ""
 };
 
-char *koi8_r_syms[] = { /* 160-255 */
-    "",                                        /* 0240 */
-    "",
-    "",
-    "cyrillic_small_letter_io",
-    "",
-    "",
-    "",
-    "",
-    "",                        /* 0250 */
-    "",
-    "",
-    "",
-    "",
-    "",
-    "",
-    "",
-    "",                        /* 0260 */
-    "",
-    "",
-    "cyrillic_capital_letter_io",
-    "",
-    "",
-    "",
-    "",
-    "",                        /* 0270 */
-    "",
-    "",
-    "",
-    "",
-    "",
-    "",
-    "copyright",
-    "cyrillic_small_letter_yu",                        /* 0300 */
-    "cyrillic_small_letter_a",
-    "cyrillic_small_letter_be",
-    "cyrillic_small_letter_tse",
-    "cyrillic_small_letter_de",
-    "cyrillic_small_letter_ie",
-    "cyrillic_small_letter_ef",
-    "cyrillic_small_letter_ghe",
-    "cyrillic_small_letter_ha",                        /* 0310 */
-    "cyrillic_small_letter_i",
-    "cyrillic_small_letter_short_i",
-    "cyrillic_small_letter_ka",
-    "cyrillic_small_letter_el",
-    "cyrillic_small_letter_em",
-    "cyrillic_small_letter_en",
-    "cyrillic_small_letter_o",
-    "cyrillic_small_letter_pe",                                /* 0320 */
-    "cyrillic_small_letter_ya",
-    "cyrillic_small_letter_er",
-    "cyrillic_small_letter_es",
-    "cyrillic_small_letter_te",
-    "cyrillic_small_letter_u",
-    "cyrillic_small_letter_zhe",
-    "cyrillic_small_letter_ve",
-    "cyrillic_small_soft_sign",                                /* 0330 */
-    "cyrillic_small_letter_yeru",
-    "cyrillic_small_letter_ze",
-    "cyrillic_small_letter_sha",
-    "cyrillic_small_letter_e",
-    "cyrillic_small_letter_shcha",
-    "cyrillic_small_letter_che",
-    "cyrillic_small_hard_sign",
-    "cyrillic_capital_letter_yu",                      /* 0340 */
-    "cyrillic_capital_letter_a",
-    "cyrillic_capital_letter_be",
-    "cyrillic_capital_letter_tse",
-    "cyrillic_capital_letter_de",
-    "cyrillic_capital_letter_ie",
-    "cyrillic_capital_letter_ef",
-    "cyrillic_capital_letter_ghe",
-    "cyrillic_capital_letter_ha",                      /* 0350 */
-    "cyrillic_capital_letter_i",
-    "cyrillic_capital_letter_short_i",
-    "cyrillic_capital_letter_ka",
-    "cyrillic_capital_letter_el",
-    "cyrillic_capital_letter_em",
-    "cyrillic_capital_letter_en",
-    "cyrillic_capital_letter_o",
-    "cyrillic_capital_letter_pe",                      /* 0360 */
-    "cyrillic_capital_letter_ya",
-    "cyrillic_capital_letter_er",
-    "cyrillic_capital_letter_es",
-    "cyrillic_capital_letter_te",
-    "cyrillic_capital_letter_u",
-    "cyrillic_capital_letter_zhe",
-    "cyrillic_capital_letter_ve",
-    "cyrillic_capital_soft_sign",                      /* 0370 */
-    "cyrillic_capital_letter_yeru",
-    "cyrillic_capital_letter_ze",
-    "cyrillic_capital_letter_sha",
-    "cyrillic_capital_letter_e",
-    "cyrillic_capital_letter_shcha",
-    "cyrillic_capital_letter_che",
-    "cyrillic_capital_hard_sign"
-};
+#include "cyrillic.syms.h"
+#include "ethiopic.syms.h"
 
 static char *fn_syms[] = {
 	"F1", 	"F2",	"F3",	"F4",	"F5",
@@ -912,9 +816,10 @@ struct cs {
     { "iso-8859-7", iso_8859_7_syms, 160 },
     { "iso-8859-8", iso_8859_8_syms, 160 },
     { "koi8-r",     koi8_r_syms, 160 },
-    { "koi8-u",     koi8_r_syms, 160 }
+    { "koi8-u",     koi8_r_syms, 160 },
 /* I don't know the differences between koi8-r and koi8-u,
    so I use the same syms table - Pablo Saratxaga */
+    { "iso-10646-18", iso_10646_18_syms, 159 },		/* ethiopic */
 };
 
 int
