@@ -4,6 +4,7 @@
  * Version 0.92
  */
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <sysexits.h>
@@ -30,6 +31,7 @@ int verbose = 0;
 int
 main(int argc, char *argv[]) {
 	int fd;
+	char *progname = argv[0];
 
 	fd = getfd();
 
@@ -42,7 +44,8 @@ main(int argc, char *argv[]) {
 	}
 		
 	if (argc > 2) {
-		fprintf(stderr,"usage: %s [-o map.orig] map-file\n",argv[0]);
+		fprintf(stderr, "usage: %s [-o map.orig] map-file\n",
+			progname);
 		exit(1);
 	}
 
@@ -243,7 +246,7 @@ loadunicodemap(int fd, char *tblname) {
 	  fprintf(stderr, "%s: trailing junk (%s) ignored\n", tblname, p);
     }
 
-    fclose(mapf);
+    fpclose(mapf);
 
     outlist();
 }
