@@ -84,7 +84,7 @@ loadnewmap(int fd, char *mfil) {
 			exit(1);
 		}
 	}
-	fclose(fp);
+	fpclose(fp);
 
 	i = ioctl(fd,PIO_SCRNMAP,buf);
 	if (i) {
