@@ -10,10 +10,16 @@
 /*
  * Default keymap, and where the kernel copy of it lives.
  */
-#define DEFMAP "defkeymap.map"
-#define KERNDIR "/usr/src/linux/drivers/char"
+#ifdef sparc
+# define DEFMAP "sunkeymap.map"
+# define KERNDIR "/usr/src/linux/drivers/sbus/char"
+#else
+# define DEFMAP "defkeymap.map"
+# define KERNDIR "/usr/src/linux/drivers/char"
+#endif
 
 extern FILE *findfile(char *fnam, char **dirpath, char **suffixes);
 extern char pathname[];
+extern void fpclose(FILE *fp);
 
 extern int verbose;
