@@ -19,6 +19,7 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <sys/kd.h>
+#include <endian.h>
 #include "paths.h"
 #include "psf.h"
 
@@ -212,6 +213,9 @@ do_loadtable(int fd, int tailsz, int fontsize, FILE *fpi) {
 	for (glyph = 0; glyph < fontsize; glyph++) {
 	    while ((i = fread(&unicode, sizeof(unicode), 1, fpi)) == 1 &&
 		   unicode != PSF_SEPARATOR) {
+#if BYTE_ORDER == BIG_ENDIAN
+		unicode = ((unicode << 8) | (unicode >> 8)) & 0xffff;
+#endif
 		if (ct >= maxct) { /* impossible */
 		    i = 0;
 		    break;
