@@ -11,6 +11,8 @@
 #include <sys/ioctl.h>
 #include <linux/kd.h>
 
+extern int getfd();
+
 void
 usage(char *s) {
     fprintf(stderr, "setkeycode: %s\n", s);
@@ -29,8 +31,8 @@ main(int argc, char **argv) {
 
     if (argc % 2 != 1)
       usage("even number of arguments expected");
-    if ((fd = open("/dev/console", 0)) < 0)
-      fd = 0;
+    fd = getfd();
+
     while (argc > 2) {
 	a.keycode = atoi(argv[2]);
 	a.scancode = sc = strtol(argv[1], &ep, 16);
