@@ -47,12 +47,12 @@ struct meta {
     char *name;
     int val;
 } metas[] = {
-    "metabit",   K_METABIT,
-    "meta",      K_METABIT,
-    "bit",       K_METABIT,
-    "escprefix", K_ESCPREFIX,
-    "esc",       K_ESCPREFIX,
-    "prefix",    K_ESCPREFIX
+    { "metabit",   K_METABIT },
+    { "meta",      K_METABIT },
+    { "bit",       K_METABIT },
+    { "escprefix", K_ESCPREFIX },
+    { "esc",       K_ESCPREFIX },
+    { "prefix",    K_ESCPREFIX }
 };
 
 #define SIZE(a) (sizeof(a)/sizeof(a[0]))
